summaryrefslogtreecommitdiffstats
path: root/kftpgrabber
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:12:57 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:12:57 -0500
commit823cb82ad32f71de4adcd77c8020c01bc4afad4d (patch)
treecf7da224fc056f4545b5f5a1beff2154734de3f4 /kftpgrabber
parentcc689d0eb0ac220e891cca6a82821d695cc1703c (diff)
downloadkftpgrabber-823cb82ad32f71de4adcd77c8020c01bc4afad4d.tar.gz
kftpgrabber-823cb82ad32f71de4adcd77c8020c01bc4afad4d.zip
Rename KWallet to TDEWallet
Diffstat (limited to 'kftpgrabber')
-rw-r--r--kftpgrabber/src/kftpbookmarks.cpp4
-rw-r--r--kftpgrabber/src/mainwindow.cpp2
-rw-r--r--kftpgrabber/src/misc/kftpgrabber.kcfg2
-rw-r--r--kftpgrabber/src/misc/kftpwalletconnection.cpp14
-rw-r--r--kftpgrabber/src/misc/kftpwalletconnection.h4
-rw-r--r--kftpgrabber/src/ui/config_general.ui2
6 files changed, 14 insertions, 14 deletions
diff --git a/kftpgrabber/src/mainwindow.cpp b/kftpgrabber/src/mainwindow.cpp
index a98d5f2..4970066 100644
--- a/kftpgrabber/src/mainwindow.cpp
+++ b/kftpgrabber/src/mainwindow.cpp
@@ -301,7 +301,7 @@ void MainWindow::initBookmarkMenu()
// Wallet menu
if (!m_walletMenu)
- m_walletMenu = new TDEActionMenu(i18n("Sites In KWallet"), loadSmallIcon("wallet_open"));
+ m_walletMenu = new TDEActionMenu(i18n("Sites In TDEWallet"), loadSmallIcon("wallet_open"));
m_bookmarkMenu->popupMenu()->insertItem(loadSmallIcon("bookmark"), i18n("Edit Bookmarks..."), 1);
m_bookmarkMenu->popupMenu()->connectItem(1, this, SLOT(showBookmarkEditor()));
diff --git a/kftpgrabber/src/misc/kftpgrabber.kcfg b/kftpgrabber/src/misc/kftpgrabber.kcfg
index 0a3c0ad..2ec861a 100644
--- a/kftpgrabber/src/misc/kftpgrabber.kcfg
+++ b/kftpgrabber/src/misc/kftpgrabber.kcfg
@@ -86,7 +86,7 @@
<entry name="showWalletSites" type="Bool">
<default>false</default>
- <label>Should the sites from KWallet be shown among the bookmarks.</label>
+ <label>Should the sites from TDEWallet be shown among the bookmarks.</label>
</entry>
<entry name="confirmDisconnects" type="Bool">
diff --git a/kftpgrabber/src/misc/kftpwalletconnection.cpp b/kftpgrabber/src/misc/kftpwalletconnection.cpp
index ca91a54..83dbe17 100644
--- a/kftpgrabber/src/misc/kftpwalletconnection.cpp
+++ b/kftpgrabber/src/misc/kftpwalletconnection.cpp
@@ -74,9 +74,9 @@ TQValueList<KURL> KFTPWalletConnection::getSiteList()
{
TQValueList<KURL> sites;
- if (!KWallet::Wallet::folderDoesNotExist(KWallet::Wallet::NetworkWallet(), KWallet::Wallet::PasswordFolder())) {
+ if (!TDEWallet::Wallet::folderDoesNotExist(TDEWallet::Wallet::NetworkWallet(), TDEWallet::Wallet::PasswordFolder())) {
if (!m_wallet) {
- m_wallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(), 0, KWallet::Wallet::Synchronous);
+ m_wallet = TDEWallet::Wallet::openWallet(TDEWallet::Wallet::NetworkWallet(), 0, TDEWallet::Wallet::Synchronous);
if (m_wallet) {
m_walletRefCount++;
@@ -88,7 +88,7 @@ TQValueList<KURL> KFTPWalletConnection::getSiteList()
return TQValueList<KURL>();
// Get the site list from our wallet
- m_wallet->setFolder(KWallet::Wallet::PasswordFolder());
+ m_wallet->setFolder(TDEWallet::Wallet::PasswordFolder());
TQStringList list = m_wallet->entryList();
TQStringList::iterator i;
@@ -118,10 +118,10 @@ TQValueList<KURL> KFTPWalletConnection::getSiteList()
TQString KFTPWalletConnection::getPassword(const TQString &whatFor)
{
- if (!KWallet::Wallet::folderDoesNotExist(KWallet::Wallet::NetworkWallet(), TQString::fromLatin1("KFTPGrabber"))) {
+ if (!TDEWallet::Wallet::folderDoesNotExist(TDEWallet::Wallet::NetworkWallet(), TQString::fromLatin1("KFTPGrabber"))) {
// We have our own folder
if (!m_wallet) {
- m_wallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(), 0, KWallet::Wallet::Synchronous);
+ m_wallet = TDEWallet::Wallet::openWallet(TDEWallet::Wallet::NetworkWallet(), 0, TDEWallet::Wallet::Synchronous);
if (m_wallet) {
m_walletRefCount++;
@@ -141,9 +141,9 @@ TQString KFTPWalletConnection::getPassword(const TQString &whatFor)
void KFTPWalletConnection::setPassword(const TQString &whatFor, const TQString &password)
{
- if (KWallet::Wallet::isEnabled()) {
+ if (TDEWallet::Wallet::isEnabled()) {
if (!m_wallet) {
- m_wallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(), 0, KWallet::Wallet::Synchronous);
+ m_wallet = TDEWallet::Wallet::openWallet(TDEWallet::Wallet::NetworkWallet(), 0, TDEWallet::Wallet::Synchronous);
if (m_wallet) {
m_walletRefCount++;
diff --git a/kftpgrabber/src/misc/kftpwalletconnection.h b/kftpgrabber/src/misc/kftpwalletconnection.h
index 34e5a4f..bd971a4 100644
--- a/kftpgrabber/src/misc/kftpwalletconnection.h
+++ b/kftpgrabber/src/misc/kftpwalletconnection.h
@@ -40,7 +40,7 @@
#include <ntqobject.h>
/**
-Enables communication of KFTPGrabber with KDE's wallet system (KWallet)
+Enables communication of KFTPGrabber with KDE's wallet system (TDEWallet)
@author Jernej Kos
*/
@@ -59,7 +59,7 @@ public:
static KFTPWalletConnection *getInstance();
private:
static KFTPWalletConnection *m_instance;
- KWallet::Wallet *m_wallet;
+ TDEWallet::Wallet *m_wallet;
uint m_walletRefCount;
private slots:
void slotWalletClosed();
diff --git a/kftpgrabber/src/ui/config_general.ui b/kftpgrabber/src/ui/config_general.ui
index 81af736..1a28094 100644
--- a/kftpgrabber/src/ui/config_general.ui
+++ b/kftpgrabber/src/ui/config_general.ui
@@ -333,7 +333,7 @@
<cstring>kcfg_showWalletSites</cstring>
</property>
<property name="text">
- <string>&amp;Show sites from KWallet among bookmarks</string>
+ <string>&amp;Show sites from TDEWallet among bookmarks</string>
</property>
</widget>
</vbox>
diff --git a/kftpgrabber/src/kftpbookmarks.cpp b/kftpgrabber/src/kftpbookmarks.cpp
index 424dd85..9c2ec32 100644
--- a/kftpgrabber/src/kftpbookmarks.cpp
+++ b/kftpgrabber/src/kftpbookmarks.cpp
@@ -344,7 +344,7 @@ pwd_entry:
content = des.output().ascii();
if (saveToWallet) {
// Save the password to KWallet
KFTPAPI::getInstance()->walletConnection()->setPassword("bookmarkDecryptPwd", p_pass);
}
}
@@ -858,7 +858,7 @@ void Manager::guiPopulateWalletMenu(TDEActionMenu *parentMenu)
parentMenu->insert(newSite);
}
} else {
- TDEAction *disabledAction = new TDEAction(i18n("<No Sites In KWallet>"));
+ TDEAction *disabledAction = new TDEAction(i18n("<No Sites In TDEWallet>"));
disabledAction->setEnabled(false);
parentMenu->insert(disabledAction);
}
@@ -344,7 +344,7 @@ pwd_entry:
content = des.output().ascii();
if (saveToWallet) {
- // Save the password to KWallet
+ // Save the password to TDEWallet
KFTPAPI::getInstance()->walletConnection()->setPassword("bookmarkDecryptPwd", p_pass);
}